from nose import tools
from sixfeetup.todo.todo import ToDo
from sixfeetup.todo.ticket import Ticket
from sixfeetup.todo import core

def ticket_repr_test():
    ticket = Ticket(
        10,
        "This is a todo item",
        "Week of 06/21/10",
        "Blocker",
        "1"
        )
    tools.assert_equal(
        ticket.__repr__(),
        "<Ticket #10>"
        )

def list_tickets_sort_test():
    tickets = []
    ta = tickets.append
    ta(Ticket(55, "This is a todo item", "Week of 06/28/10", "Blocker", "1"))
    ta(Ticket(5, "Done by friday", "Week of 06/21/10", "Friday", "1"))
    ta(Ticket(7, "This is a todo item", "Ongoing", "Minor", "None"))
    ta(Ticket(10, "Done monday first", "Week of 06/21/10", "Monday", "2"))
    ta(Ticket(99, "This would be first", "Week of 06/21/10", "Blocker", "None"))
    ta(Ticket(9, "Last for week of the 21st", "Week of 06/21/10", "Tuesday", "None"))
    ta(Ticket(88, "Done monday 2nd", "Week of 06/21/10", "Monday", "10"))
    # they are in the order we added them as
    tools.assert_equal(
        repr(tickets),
        '[<Ticket #55>, <Ticket #5>, <Ticket #7>, <Ticket #10>, <Ticket #99>, <Ticket #9>, <Ticket #88>]',
        "You messed up the sort order"
    )
    # now let's sort and test
    tickets.sort()
    tools.assert_equal(
        repr(tickets),
        '[<Ticket #99>, <Ticket #10>, <Ticket #88>, <Ticket #9>, <Ticket #5>, <Ticket #55>, <Ticket #7>]',
        "Order is not applying to the list properly: %s" % tickets
    )

def compare_milestone_test():
    ticket1 = Ticket(
        88,
        "Done monday 2nd",
        "Week of 06/21/10",
        "Monday",
        "10",
        )
    ticket2 = Ticket(
        88,
        "Done monday 2nd",
        "Week of 06/28/10",
        "Monday",
        "10",
        )
    ticket3 = Ticket(
        88,
        "Done monday 2nd",
        "Ongoing Work",
        "Monday",
        "10",
        )
    ticket4 = Ticket(
        88,
        "Done monday 2nd",
        "Alphabet",
        "Monday",
        "10",
        )
    # 6/21 v. 6/28
    tools.assert_equal(-1, cmp(ticket1, ticket2))
    # 6/28 v. Ongoing
    tools.assert_equal(-1, cmp(ticket2, ticket3))
    # Ongoing v. Alpha
    tools.assert_equal(1, cmp(ticket3, ticket4))

def compare_flag_test():
    ticket1 = Ticket(
        88,
        "Summary",
        "Moot",
        "Monday",
        "5",
        )
    ticket2 = Ticket(
        88,
        "Summary",
        "Moot",
        "Monday",
        "10",
        )
    ticket3 = Ticket(
        88,
        "Summary",
        "Moot",
        "Monday",
        "None",
        )
    ticket4 = Ticket(
        88,
        "Summary",
        "Moot",
        "Monday",
        "foo bar",
        )
    # 5 v. 10
    tools.assert_equal(-1, cmp(ticket1, ticket2))
    # 10 v. None
    tools.assert_equal(-1, cmp(ticket2, ticket3))
    # 9999 v. 9999
    tools.assert_equal(1, cmp(ticket3, ticket4))

def compare_priority_test():
    ticket1 = Ticket(
        88,
        "Summary",
        "Moot",
        "Monday",
        "10",
        )
    ticket2 = Ticket(
        88,
        "Summary",
        "Moot",
        "Tuesday",
        "10",
        )
    ticket3 = Ticket(
        88,
        "Summary",
        "Moot",
        "Sunday",
        "10",
        )
    ticket4 = Ticket(
        88,
        "Summary",
        "Moot",
        "Blocker",
        "10",
        )
    ticket5 = Ticket(
        88,
        "Summary",
        "Moot",
        "Something Else",
        "10",
        )
    # Monday v. Tuesday
    tools.assert_equal(-1, cmp(ticket1, ticket2))
    # Tuesday v. Sunday
    tools.assert_equal(-1, cmp(ticket2, ticket3))
    # Monday v. Blocker
    tools.assert_equal(1, cmp(ticket1, ticket4))
    # Blocker v. Something Else
    tools.assert_equal(-1, cmp(ticket4, ticket5))
