import calendar


class Ticket(object):
    """An object that represents a ticket. The important part of this
    object is that it can compare itself to other ticket objects in
    order to sort them by a complex algorithm.
    """

    def __init__(self, id, summary, milestone, priority, flag):
        self.id = id
        self.summary = summary
        self.milestone = milestone
        self.priority = priority
        self.flag = flag

    def __repr__(self):
        return "<Ticket #%s>" % self.id

    def __cmp__(self, other):
        """This is effin' nutso. Bear with me here.

       Sort by the following:

            - Milestone
              - "Week of ..." goes first
            - Priority
              - Non days go first
              - Then by order of weekday
            - Flag
              - Integers sort normally and come first
              - 'None' is last
              - Any other flag will come before 'None'
        """
        milestone = self.milestone.lower()
        other_milestone = other.milestone.lower()
        priority = self.priority.lower()
        other_priority = other.priority.lower()
        weekdays = [day.lower() for day in calendar.day_name]
        wix = weekdays.index
        # milestone and priority are the same, so we compare with the flag
        if milestone == other_milestone and priority == other_priority:
            return cmp(self.flag_int, other.flag_int)
        # milestones are the same, but priorities differ
        if milestone == other_milestone and priority != other_priority:
            # priorities that are not day names come first
            if priority in weekdays and other_priority not in weekdays:
                return 1
            # if we are dealing with two days, compare their index in
            # the weekday list
            elif priority in weekdays and other_priority in weekdays:
                return cmp(wix(priority), wix(other_priority))
            # otherwise just compare the strings
            else:
                return cmp(priority, other_priority)
        # milestones are not the same
        if milestone != other_milestone:
            m_weekof = milestone.startswith("week of")
            o_weekof = other_milestone.startswith("week of")
            # both start with 'week of' compare them directly
            if m_weekof and o_weekof:
                return cmp(milestone, other_milestone)
            # the other item is something other than 'week of'
            elif m_weekof and not o_weekof:
                return -1
            # this item is something other than 'week of'
            elif not m_weekof and o_weekof:
                return 1
            # neither are 'week of' compare them directly
            else:
                return cmp(milestone, other_milestone)

    @property
    def flag_int(self):
        """Convert the string flag var into an integer. If the string is
        'None' then it should be last. If the string is anything that
        doesn't convert into an integer then it should be just before
        last.
        """
        try:
            flag = int(self.flag)
        except ValueError:
            if self.flag.lower() == "none":
                flag = 9999
            else:
                flag = 9998
        return flag
